@@ -20,7 +20,7 @@ def extract_rules_from_tree(
     features_names: List[str] = None,
     classes_names: List[str] = None,
     get_leaf: bool = False,
-    remember_activation: bool = True,
+    compute_activation: bool = True,
     stack_activation: bool = False,
 ) -> RuleSet:
     """To extract rules from a sklearn decision tree
@@ -79,9 +79,9 @@ def extract_rules_from_tree(
         max values of each xs, one entry per x
     get_leaf: Boolean type
         To return only the leaf of the tree.
-    remember_activation: bool
+    compute_activation: bool
         The activation of the RuleSet is the logical OR of the activation of all its rules. It is only computed
-        if remember_activation is True. (default value = True)
+        if compute_activation is True. (default value = True)
     stack_activation: bool
         If True, the RuleSet will keep in memory 2-D np.ndarray containing the activations of all its rules. This
         can take a lot of memory, but can save time if you apply numpy methods on this stacked vector instead of on
@@ -99,7 +99,7 @@ def extract_rules_from_tree(
 
     def visitor(node, depth, condition=None, rules_list=None):
         if rules_list is None:
-            rules_list = RuleSet(remember_activation=remember_activation, stack_activation=stack_activation)
+            rules_list = RuleSet(compute_activation=compute_activation, stack_activation=stack_activation)
         if decision_tree.feature[node] != _tree.TREE_UNDEFINED:
             # If
             new_condition = HyperrectangleCondition(
